PCB Environment: PCBItemSets Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
PCBItemSets Struct Reference

## Public Member Functions
| PCBItemSets (std::set< Component * > *com=0, std::set< Pin * > *pin=0, std::set< Net * > *net=0, std::set< Connection * > *con=0)
void | populate (PCBoard &, PyObject *)
void | clear ()
void | complement (PCBoard &)
void | populateComsFromPins ()
void | populateComsFromNets ()
void | populateComsFromConnections ()
void | populatePinsFromComs ()
void | populatePinsFromNets ()
void | populatePinsFromConnections ()
void | populateNetsFromComs ()
void | populateNetsFromPins ()
void | populateNetsFromConnections ()
void | populateConnectionsFromComs ()
void | populateConnectionsFromPins ()
void | populateConnectionsFromNets ()
void | prune (PCBoard &)

## Data Fields
std::set< Component * > * | coms
std::set< Component * > | _coms
std::set< Pin * > * | pins
std::set< Pin * > | _pins
std::set< Net * > * | nets
std::set< Net * > | _nets
std::set< Connection * > * | cons
std::set< Connection * > | _cons

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/PCBItemSets.hpp